# CoinMarketCap API Wrapper in Python

With cmcapi you can monitoring and watch the crypto market more conveniently, and this library has been tested with Python 3.7.x.
Please also refer official API doc: [Coinmarketcap API](https://coinmarketcap.com/api/documentation/v1/#tag/cryptocurrency)

# Usage
